#!/bin/bash

# Check if a path argument is provided
if [ "$#" -ne 1 ]; then
    echo "Usage: $0 <path_to_tests>"
    exit 1
fi

test_path=$1
script_dir="$(dirname "$0")"
test_list_file="$script_dir/should-pass.txt"
failed_tests_file="$script_dir/failed.txt"

# Ensure the test list file exists
if [ ! -f "$test_list_file" ]; then
    echo "Error: Test list file ($test_list_file) not found!"
    exit 1
fi

# Clear the failed tests file
> "$failed_tests_file"

# Read each test name from the list
while read -r test_name; do
    echo "Searching for test: $test_name"
    
    # Find the test script (assuming they are JavaScript files)
    test_script=$(find "$test_path" -type f -name "$test_name" | head -n 1)
    
    if [ -z "$test_script" ]; then
        echo "Test not found: $test_name"
        continue
    fi

    echo "Running test: $test_script"
    /usr/bin/node "$test_script"
    exit_code=$?
    
    if [ $exit_code -ne 0 ]; then
        echo "$test_name" >> "$failed_tests_file"
        echo "Test failed: $test_name (Exit code: $exit_code)"
    else
        echo "Test passed: $test_name"
    fi
    
    echo "--------------------------"
done < "$test_list_file"

echo "Test execution complete. Failed tests stored in $failed_tests_file"

